@@ -41,7 +41,7 @@
 #' @param base  Main directory of DWD ftp server, defaulting to observed climatic records.
 #'              DEFAULT: [`dwdbase`]
 #' @param dir   Char: writeable directory name where to save the main output(s).
-#'              Created if not existent. DEFAULT: "DWDdata" at current [getwd()]
+#'              Created if not existent. DEFAULT: [locdir()]
 #' @param fname Char: Name of file in `dir` in which to write [`fileIndex`].
 #'              Use `fname=""` to suppress writing. DEFAULT: "fileIndex.txt"
 #' @param meta  Logical: should metaIndex also be created from fileIndex?
@@ -58,6 +58,7 @@
 #'              If not, "_n" is added to the filenames, see
 #'              [berryFunctions::newFilename()].
 #'              DEFAULT: FALSE
+#' @param check Logical: run [checkIndex()]? DEFAULT: TRUE
 #' @param checkwarn Logical: warn about [checkIndex()] issues? DEFAULT: TRUE
 #' @param checklog Logfile for [checkIndex()]. DEFAULT: [tempfile()]
 #' @param quiet Logical: Suppress messages about progress and filenames?
@@ -67,13 +68,14 @@
 createIndex <- function(
 paths,
 base=dwdbase,
-dir="DWDdata",
+dir=locdir(),
 fname="fileIndex.txt",
 meta=FALSE,
 metadir="meta",
 mname="metaIndex.txt",
 gname="geoIndex.txt",
 overwrite=FALSE,
+check=TRUE,
 checkwarn=TRUE,
 checklog=tempfile(),
 quiet=rdwdquiet(),
@@ -100,27 +102,42 @@ messaget <- function(x) message(x, " (",
 # clipr::write_clip(dd)
 # https://docs.google.com/spreadsheets/d/1qXQ1bSLW5TJnJgpUXIID3mVNYS6YZaHbsoe22LmBIAk/edit#gid=0
 
-# All paths should have the same amount of levels before being splitted:
-err <- "1_minute/precipitation/historical/2021/1minutenwerte_nieder1minutenwerte_nieder_000_hist.zip"
-paths <- paths[paths!=err] ; rm(err)
+ # remove leading slashes:
+paths <- sub("^/","",paths)
 fileIndex <- paths
+# All paths should have the same amount of levels before being splitted:
+subdesc <- function(d)
+  {
+  sel <- grepl(d, fileIndex, fixed=TRUE) & 
+        !grepl("multi_annual", fileIndex, fixed=TRUE) &
+        !grepl("subdaily/standard_format", fileIndex, fixed=TRUE)
+  sel <- which(sel)
+  sel <- sel[lengths(gregexpr("/", fileIndex[sel], fixed=TRUE))==2] # res/var/file instead of res/var/per/file
+  fileIndex[sel] <- sub(d, paste0("/ ",d), fileIndex[sel], fixed=TRUE)
+  fileIndex
+  }
+fileIndex <- subdesc("/BESCHREIBUNG")
+fileIndex <- subdesc("/DESCRIPTION")
 s <- function(pat, rep) sub(pat, rep, fileIndex, fixed=TRUE)
-fileIndex <- s("y/solar/", "y/solar//") # only hourly + daily, not the others
+fileIndex <- s("y/solar/t", "y/solar//t") # only hourly + daily, not the others
+fileIndex <- s("y/solar/S", "y/solar//S")
+fileIndex <- s("y/solar/s", "y/solar//s")
 fileIndex <- s("multi_annual/", "multi_annual//")
 fileIndex <- s("subdaily/standard_format/", "subdaily/standard_format//")
-fileIndex <- s( "1_minute/precipitation/historical/", "1_minute/precipitation/historical|")
-fileIndex <- s("5_minutes/precipitation/historical/","5_minutes/precipitation/historical|")
+fileIndex <- s( "1_minute/precipitation/historical/1", "1_minute/precipitation/historical|1")
+fileIndex <- s( "1_minute/precipitation/historical/2", "1_minute/precipitation/historical|2")
+fileIndex <- s("5_minutes/precipitation/historical/1","5_minutes/precipitation/historical|1")
+fileIndex <- s("5_minutes/precipitation/historical/2","5_minutes/precipitation/historical|2")
 fileIndex <- s("climate_indices/","climate_indices|")
-rm(s)
- # remove leading slashes:
-fileIndex <- sub("^/","",fileIndex)
+rm(s, subdesc)
 # split into parts:
 if(!quiet) messaget("Splitting filenames...")
 fileIndex <- strsplit(fileIndex,"/", fixed=TRUE)
 # check if there are actually 4 columns:
 ln4 <- lengths(fileIndex)!=4
 if(any(ln4)) tstop("paths should have 4 elements (res/var/per/file), not ", 
-                   toString(unique(lengths(fileIndex)[ln4])))
+                   toString(unique(lengths(fileIndex)[ln4])), ". First few out of ",sum(ln4),":\n- ",
+                   paste(na.omit(sapply(fileIndex[ln4], paste, collapse="/")[1:3]), collapse="\n- "))
 rm(ln4)
 fileIndex <- data.frame(t(simplify2array(fileIndex))) # much faster than l2df
 colnames(fileIndex) <- c("res","var","per","file")
@@ -217,7 +234,7 @@ sapply(2:length(cnames), function(i) if(!all(cnames[[i]] == cnames[[1]]))
          "\n instead of \n", toString(cnames[[1]]), skip=2))
 #
 # merge:
-if(!quiet) messaget("Merging meta files...")
+if(!quiet) messaget("Merging meta files (expect 1 minute) ...")
 metaIndex <- Reduce(function(...) merge(..., all=TRUE), metas)
 if(!quiet) messaget("Processing meta files...")
 metaIndex$Stationsname <- berryFunctions::convertUmlaut(metaIndex$Stationsname)
@@ -298,6 +315,7 @@ geoIndex$res <- NULL
 geoIndex$var <- NULL
 geoIndex$per <- NULL
 geoIndex$hasfile <- NULL
+geoIndex$Abgabe <- NULL # removed since 2025-08-01
 #
 # reduction into unique stations:
 geoIndex <- geoIndex[!duplicated(geoIndex), ]  #  ca 6k rows (=unique station IDs)
@@ -318,7 +336,8 @@ if(gname!="")
   }
 #
 # Check all indexes:
-checks <- checkIndex(fileIndex, metaIndex, geoIndex, fast=TRUE, warn=checkwarn,
+checks <- if(!check) "checkIndex suppressed with check=FALSE" else
+          checkIndex(fileIndex, metaIndex, geoIndex, fast=TRUE, warn=checkwarn,
                      quiet=quiet, logfile=checklog)
 #
 # Output -----------------------------------------------------------------------
