@@ -17,7 +17,7 @@
 #'         if `read=TRUE`, the desired dataset
 #'         (as returned by [readDWD()]),
 #'         otherwise the filename as saved on disc
-#'         (may have "_n" appended in name, see [newFilename()]).\cr
+#'         (may have "_n" appended in name, see [berryFunctions::newFilename()]).\cr
 #'         If length(file)>1, the output is a list of outputs / vector of filenames.\cr
 #'         The output is always invisible.
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Jun-Oct 2016
@@ -37,7 +37,7 @@
 #' link <- selectDWD("Fuerstenzell", res="hourly", var="wind", per="recent")
 #' # download file:
 #' fname <- dataDWD(link, dir=locdir(), read=FALSE) ; fname
-#' # dir="DWDdata" is the default directory to store files
+#' # dlocdir() is the default directory to store files
 #' # unless force=TRUE, already obtained files will not be downloaded again
 #' 
 #' # read and plot file:
@@ -45,9 +45,8 @@
 #' metafiles <- readMeta(fname)          ; str(metafiles, max.level=1)
 #' column_names <- readVars(fname)       ; head(column_names)
 #' 
-#' plot(wind$MESS_DATUM, wind$F, main="DWD hourly wind Fuerstenzell", col="blue",
-#'      xaxt="n", las=1, type="l", xlab="Date", ylab="Hourly Wind speed  [m/s]")
-#' berryFunctions::monthAxis(1)
+#' plotDWD(wind, "F.Windgeschwindigkeit", main="DWD hourly wind Fuerstenzell", 
+#'         ylab="Hourly Wind speed  [m/s]", lwd=1)
 #' 
 #' 
 #' # current and historical files, keep historical in the overlap time period:
@@ -60,7 +59,7 @@
 #' #links <- selectDWD(res="daily", var="solar")
 #' #sol <- dataDWD(links, sleep=20) # random waiting time after download (0 to 20 secs)
 #' 
-#' # Real life examples can be found in the use cases section of the vignette:
+#' # Real life examples can be found in the use cases section of the website:
 #' # browseURL("https://bookdown.org/brry/rdwd")
 #' }
 #' 
@@ -77,6 +76,8 @@
 #'               Use NA to force re-downloading files older than 24 hours.
 #'               Use a numerical value to force after that amount of hours.
 #'               Use something like `c(Inf, 24)` or `force=c(24*365, 6)`, for per="hr".
+#'               Use `force=rep(c(365*24, 6), each=3)` if you selected 
+#'               3 stations with per="hr" in [selectDWD()].
 #'               Note: if `force` is not FALSE, the `overwrite` default is TRUE.
 #'               DEFAULT: FALSE
 #' @param overwrite Logical (vector): if force=TRUE, overwrite the existing file
@@ -165,7 +166,9 @@ if(browse)
 owd <- dirDWD(dir, quiet=quiet)
 on.exit(setwd(owd))
 # output file name(s)
+hbas <- sub("^ftp://","https://", base) # for https base
 outfile <- gsub(paste0(base,"/"), "", url)
+outfile <- gsub(paste0(hbas,"/"), "", outfile)
 outfile <- gsub("/", "_", outfile)
 
 # force=NA management
@@ -215,15 +218,16 @@ if(any(iserror))
                 " failed (out of ",length(iserror),").",
                 if(read)" Setting read=FALSE.")
   read <- FALSE
-  msg <- paste0(msg, " download.file error",if(ne>1) "s",":\n")
-  msg2 <- sapply(dl_results[iserror], function(e)attr(e,"condition")$message)
-  msg2 <- berryFunctions::truncMessage(msg2, ntrunc=15, prefix="", midfix="", altnix="", sep="\n")
-  if(any(substr(url[iserror], 1, 4) != "ftp:"))
-     msg2 <- paste0(msg2, "\n- dataDWD needs urls starting with 'ftp://'. You can use joinbf=TRUE for relative links.")
-  if(grepl("cannot open URL", msg2) || grepl("Kann URL .* nicht", msg2))
-     msg2 <- paste0(msg2, "\n- If files have been renamed on the DWD server, ",
+  msg2 <- paste0("\n- download.file error",if(ne>1) "s",":\n")
+  msg3 <- sapply(dl_results[iserror], function(e)attr(e,"condition")$message)
+  msg3 <- berryFunctions::truncMessage(msg3, ntrunc=15, prefix="", midfix="", altnix="", sep="\n")
+  if(any(!substr(url[iserror], 1, 4) %in% c("ftp:","http")))
+     msg <- paste0(msg, "\n- dataDWD needs urls starting with 'ftp://' or 'https://'. ",
+                    "You can use joinbf=TRUE for relative links.")
+  if(grepl("cannot open URL", msg3) || grepl("Kann URL .* nicht", msg3))
+     msg <- paste0(msg, "\n- If files have been renamed on the DWD server, ",
                     "see   https://bookdown.org/brry/rdwd/fileindex.html")
-  msg <- paste0(msg, msg2)
+  msg <- paste0(msg, msg2, msg3)
   warning(msg, call.=FALSE)
   }
 # ------------------------------------------------------------------------------
