@@ -244,9 +244,12 @@ return(output)
 #'                 DEFAULT: FALSE (for backwards compatibility)
 #' @param format   Char (vector): Format passed to [as.POSIXct()] (see [strptime()])
 #'                 to convert the date/time column to POSIX time format.\cr
+#'                 If NA (the default), `readDWD` tries to find a suitable format 
+#'                 based on the number of characters. 
+#'                 Since rdwd version 1.8.7 (2024-05-14), timestamps with 8 digits
+#'                 (e.g. in daily data) is converted with [as.Date()].
 #'                 If NULL, no conversion is performed (date stays a factor).
-#'                 If NA, `readDWD` tries to find a suitable format based
-#'                 on the number of characters. DEFAULT: NA
+#'                 DEFAULT: NA
 #' @param tz       Char (vector): time zone for [as.POSIXct()].
 #'                 "" is the current time zone, and "GMT" is UTC (Universal Time,
 #'                 Coordinated). DEFAULT: "GMT"
@@ -308,10 +311,12 @@ if(!is.null(format))
     twarning("There is no column 'MESS_DATUM' in ",file) else
     {
     nch <- nchar(as.character(dat$MESS_DATUM[1]))
-    if(is.na(format)) format <- if(nch== 8) "%Y%m%d" else
-                                if(nch==12) "%Y%m%d%H%M" else # for 201804270020 10min data
-                                if(nch==13) "%Y%m%d%H:%M" else"%Y%m%d%H"
+    naformat <- is.na(format)
+    if(naformat) format <- if(nch== 8) "%Y%m%d" else
+                           if(nch==12) "%Y%m%d%H%M" else # for 201804270020 10min data
+                           if(nch==13) "%Y%m%d%H:%M" else"%Y%m%d%H"
     dat$MESS_DATUM <- as.POSIXct(as.character(dat$MESS_DATUM), format=format, tz=tz)
+    if(naformat && nch==8) dat$MESS_DATUM <- as.Date(dat$MESS_DATUM)
     }
   }
 # final output:
@@ -380,8 +385,9 @@ return(dat)
 #' # Temperature aggregates (2019-04 the 9th file, 2022-05 the 8th):
 #' durl <- selectDWD(res="multi_annual", per="mean_81-10")[8]
 #' murl <- selectDWD(res="multi_annual", per="mean_81-10", meta=TRUE)[8]
-#' ma_temp <- dataDWD(durl, fileEncoding="")
-#' ma_meta <- dataDWD(murl, fileEncoding="")
+#' # encoding issue not tested enough to be in the source code:
+#' ma_temp <- dataDWD(durl)
+#' ma_meta <- dataDWD(murl)
 #' 
 #' head(ma_temp)
 #' head(ma_meta)
@@ -415,19 +421,26 @@ return(dat)
 #' @param file  Name of file on harddrive, like e.g.
 #'              DWDdata/multi_annual_mean_81-10_Temperatur_1981-2010_aktStandort.txt or
 #'              DWDdata/multi_annual_mean_81-10_Temperatur_1981-2010_Stationsliste_aktStandort.txt
-#' @param fileEncoding [read.table()] file encoding.
-#'              DEFAULT: "latin1"
+#' @param fileEncoding [read.table()] file encoding. DEFAULT: "latin1"
+#' @param tryenc Logical. If reading fails, try with encoding ="". This was added
+#'              in version 1.8.5 (2023-09-27) because of non-reproducible 
+#'              issues in runLocalTests.
+#'              DEFAULT: TRUE
 #' @param comment.char [read.table()] comment character.
 #'              DEFAULT: "\\032" (needed 2019-04 to ignore the binary
 #'              control character at the end of multi_annual files)
 #' @param quiet Ignored.
 #'              DEFAULT: FALSE through [rdwdquiet()]
 #' @param \dots Further arguments passed to [read.table()]
-readDWD.multia <- function(file, fileEncoding="latin1", comment.char="\032",
-                           quiet=rdwdquiet(), ...)
+readDWD.multia <- function(file, fileEncoding="latin1", tryenc=TRUE,
+                           comment.char="\032", quiet=rdwdquiet(), ...)
 {
-out <- read.table(file, sep=";", header=TRUE, fileEncoding=fileEncoding,
-                  comment.char=comment.char, ...)
+out <- suppressWarnings(try(read.table(file, sep=";", header=TRUE, fileEncoding=fileEncoding,
+                      comment.char=comment.char, ...), silent=TRUE))
+if(tryenc) if(inherits(out, "try-error") || nrow(out)==0) # try with encoding ""
+out <- try(read.table(file, sep=";", header=TRUE, fileEncoding="",
+                      comment.char=comment.char, ...), silent=TRUE)
+if(inherits(out, "try-error")) stop(out)
 nc <- ncol(out)
 # presumably, all files have a trailing empty column...
 if(colnames(out)[nc]=="X") out <- out[,-nc]
@@ -573,7 +586,7 @@ return(sf)
 #' head(meta)
 #' 
 #' cnm <- colnames(meta)
-#' if(length(cnm)!=8) stop("number of columns should be 8, but is ", length(cnm),
+#' if(length(cnm)!=9) stop("number of columns should be 9, but is ", length(cnm),
 #'                         ":\n", toString(cnm))
 #' }
 #' @param file  Name of file on harddrive, like e.g.
@@ -605,19 +618,22 @@ widths <- diff(c(0,breaks,200))
 # actually read metadata, suppress readLines warning about EOL:
 stats <- suppressWarnings(read.fwf(file, widths=widths, skip=2, strip.white=TRUE,
                                    fileEncoding="latin1", ...) )
-colnames(stats) <- cnames
-if(grepl("subdaily_standard_format", file))
+if(!grepl("subdaily_standard_format", file)) colnames(stats) <- cnames
+if( grepl("subdaily_standard_format", file))
  {
- stats <- stats[ ! stats[,1] %in% c("","ST_KE","-----") , ]
+ # deal with special file 2025-01-23:
+ stats <- stats[ ! stats[,1] %in% c("","ST_KE","-----","10XXX") , ]
  tf <- tempfile()
  write.table(stats[,-1], file=tf, quote=FALSE, sep="\t")
  stats <- read.table(tf, sep="\t")
  colnames(stats) <- c("Stations_id", "von_datum", "bis_datum", "Stationshoehe",
-                      "geoBreite", "geoLaenge", "Stationsname", "Bundesland")
+                      "geoBreite", "geoLaenge", "Stationsname", "Bundesland") # , "Abgabe")
  }
+# add column if not present (added 2025-01-23)
+if(!"Abgabe" %in% colnames(stats)) stats$Abgabe <- "---"
 # check classes:
-if(ncol(stats)!=8) tstop(ncol(stats)," columns detected instead of 8 for ", file)
-classes <- c("integer", "integer", "integer", "integer", "numeric", "numeric", "character", "character")
+if(ncol(stats)!=9) tstop(ncol(stats)," columns detected instead of 9 for ", file)
+classes <- c("integer", "integer", "integer", "integer", "numeric", "numeric", "character", "character", "character")
 actual <- sapply(stats, class)
 if(actual[4]=="numeric") classes[4] <- "numeric"
 if(!all(actual == classes))
@@ -822,7 +838,7 @@ return(invisible(r))
 #' if toraster=FALSE, a list with time, lat, lon, var, varname, file and cdf.
 #' **cdf** is the output of [ncdf4::nc_open()].
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Aug 2019
-#' @seealso [readDWD()]
+#' @seealso [readDWD.hyras()] for non-packed .nc files, [readDWD()] 
 #' @importFrom utils menu tail capture.output
 #' @examples
 #' \dontrun{ # Excluded from CRAN checks, but run in localtests
@@ -858,8 +874,12 @@ return(invisible(r))
 #' @param gargs       Named list of arguments passed to
 #'                    [R.utils::gunzip()], see [readDWD.raster()]. DEFAULT: NULL
 #' @param toraster    Read file with [terra::rast()]?
-#'                    All further arguments will be ignored. Specify e.g. `var` 
-#'                    through \dots as `varname`. DEFAULT: TRUE
+#'                    All further arguments (except noflip) will be ignored.
+#'                    Specify e.g. `var` through \dots as `varname`.
+#'                    DEFAULT: TRUE
+#' @param noflip      Vertical flip in [terra::rast()]? 
+#'                    Can probably always be TRUE, see https://github.com/rspatial/terra/issues/1764.
+#'                    DEFAULT: TRUE
 #' @param var         if toraster=FALSE: Charstring with name of variable to be read with
 #'                    [ncdf4::ncvar_get()]. If not available,
 #'                    an interactive selection is presented.
@@ -868,7 +888,7 @@ return(invisible(r))
 #'                    DEFAULT: FALSE through [rdwdquiet()]
 #' @param \dots       Further arguments passed to [terra::rast()] or [ncdf4::nc_open()]
 #' 
-readDWD.nc <- function(file, gargs=NULL, var="", toraster=TRUE, quiet=rdwdquiet(), ...)
+readDWD.nc <- function(file, gargs=NULL, var="", toraster=TRUE, noflip=TRUE, quiet=rdwdquiet(), ...)
 {
 checkSuggestedPackage("ncdf4", "rdwd:::readDWD.nc") # also needed if toraster=TRUE
 checkSuggestedPackage("R.utils", "rdwd:::readDWD.nc")
@@ -881,7 +901,7 @@ if(toraster)
   {
   checkSuggestedPackage("terra", "rdwd:::readDWD.nc with toraster=TRUE")
   # ignore ncdf print, see https://github.com/rspatial/raster/issues/143
-  capture.output(out <- terra::rast(ncfile, ...))
+  capture.output(out <- terra::rast(ncfile, noflip=noflip, ...))
   return(invisible(out))
   }
 #
@@ -930,6 +950,37 @@ return(invisible(list(time=time, lat=LAT, lon=LON, var=VAR, varname=var,
 
 
 
+# ~ hyras ----
+
+#' @title read dwd hyras netcdf data
+#' @description Read hyras netcdf data.
+#' Intended to be called via [readDWD()].\cr
+#' Note that `terra` must be installed to read the .nc files.
+#' @return [terra::rast()] object.
+#' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Jun 2023
+#' @seealso [readDWD.nc()] for packed .nc.gz files, [readDWD()]
+#' @examples
+#' \dontrun{ # Excluded from CRAN checks, but run in localtests
+#' link <- "monthly/hyras_de/humidity/hurs_hyras_5_2020_v5-0_de_monmean.nc"
+#' hyras <- dataDWD(link, gridbase, joinbf=TRUE) # 0.9MB
+#' plotRadar(hyras, proj="nc", extent=NULL, 
+#'           main=substr(terra::time(hyras),1,7), layer=1:2)
+#' }
+#' @param file        Name of file on harddrive, like e.g.
+#'                    DWDdata/monthly_hyras_de_humidity_hurs_hyras_5_2020_v5-0_de_monmean.nc
+#' @param quiet       Currently not used.
+#'                    DEFAULT: FALSE through [rdwdquiet()]
+#' @param \dots       Further arguments passed to [terra::rast()]
+#' 
+readDWD.hyras <- function(file, quiet=rdwdquiet(), ...)
+{
+checkSuggestedPackage("terra", "rdwd:::readDWD.hyras")
+out <- terra::rast(file, ...)
+return(invisible(out))
+}
+
+
+
 # ~ radar ----
 
 #' @title read dwd gridded radolan radar data
@@ -1085,6 +1136,56 @@ return(invisible(dat))
 
 
 
+# ~ asczip ----
+
+#' @title read dwd gridded asc data
+#' @description Read gridded asc data.
+#' Intended to be called via [readDWD()].\cr
+#' @return [`terra::rast`] object
+#' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Jan 2025
+#' @seealso [readDWD()]
+#' @examples
+#' \dontrun{ # Excluded from CRAN checks, but run in localtests
+#' link <- "annual/radiation_global/grids_germany_annual_radiation_global_2022.zip" # 0.1 MB
+#' file <- dataDWD(link, base=gridbase, joinbf=TRUE, read=FALSE)
+#' meta <- readDWD(file, ascmeta=TRUE)
+#' str(meta)
+#' grid <- readDWD(file)
+#' plotRadar(grid, proj="seasonal", extent="seasonal")
+#' }
+#' @param file        Name of file on harddrive, like e.g.
+#'                    DWDdata/annual/radiation_global/grids_germany_annual_radiation_global_2024.zip
+#' @param ascmeta     Logical: return meta data from asc file as a vector with ca 20 string elements?
+#'                    DEFAULT: FALSE
+#' @param quiet       Ignored.
+#'                    DEFAULT: FALSE through [rdwdquiet()]
+#' @param \dots       Further arguments passed to [terra::rast()]
+readDWD.asczip <- function(file, ascmeta=FALSE, quiet=rdwdquiet(), ...)
+{
+checkSuggestedPackage("terra",  "rdwd:::readDWD.asczip")
+# temporary unzipping directory
+fn <- tools::file_path_sans_ext(basename(file))
+exdir <- paste0(tempdir(),"/", fn)
+unzip(file, exdir=exdir)
+on.exit(unlink(exdir, recursive=TRUE), add=TRUE)
+# Prepare the actual data file:
+f <- dir(exdir, full.names=TRUE)
+if(length(f)!=1) tstop("There should be a single file (.asc), but there are ",
+                      length(f), " in\n  ", file, ".")
+asc <- readLines(f)
+marker <- which(asc=="[ASCII-Raster-Format]")
+if(ascmeta)
+  return(asc[2:(marker-1)])
+# remove metadata part:
+f <- berryFunctions::normalizePathCP(paste0(tempdir(),"/", basename(f)))
+writeLines(asc[(marker+1):length(asc)], f)
+# raster reading:
+r <- terra::rast(f, ...)
+return(invisible(r))
+}
+
+
+
 # ~ rklim ----
 
 #' @title read dwd gridded radklim binary data
@@ -1266,6 +1367,14 @@ return(invisible(list(dat=rbmat, meta=rbmeta)))
 #' for(f in unique(substr(grib_files, 1,3))) print(grib_files[which(substr(grib_files, 1,3)==f)[1]])
 #' View(data.frame(grep("regular",grib_files, value=TRUE)))
 #' }
+#' 
+#' # Project_TRY bz2 netcdf data:
+#' url <- "hourly/Project_TRY/air_temperature_mean/TT_201102.nc.bz2" # 97 MB
+#' file <- dataDWD(url, base=gridbase, joinbf=TRUE, dir=tempdir(), read=FALSE)
+#' nc <- readDWD(file) # should also be using readDWD.grib2
+#' # Setting layer=1:2 takes 4 minutes, just go one at a time, I guess:
+#' ncp <- plotRadar(nc, main=paste(terra::longnames(nc), terra::time(nc)), layer=1,
+#'                  col=berryFunctions::seqPal(), proj="nc", extent="nc")
 #' }
 #' @param file      Name of file on harddrive, like e.g.
 #'                  cosmo-d2_germany_regular-lat-lon_single-level_2021010100_005_T_2M.grib2.bz2
@@ -1289,6 +1398,9 @@ quiet=rdwdquiet(),
 ...)
 {
 checkSuggestedPackage("R.utils", "rdwd:::readDWD.grib2")
+# if(grepl(".nc", file, fixed=TRUE)) checkSuggestedPackage("ncdf4", "rdwd:::readDWD.grib2 for nc files")
+# works without ncdf4 installed, gives Warning [rast] GDAL did not find an extent. installing the ncdf4 package may help 
+# but plotRadar sets the extent just fine
 # bunzip arguments:
 bdef <- list(filename=file, remove=FALSE, skip=TRUE)
 bfinal <- berryFunctions::owa(bdef, bargs, "filename")
@@ -1327,9 +1439,16 @@ return(invisible(out))
 #' @seealso [readDWD()]
 #' @examples
 #' \dontrun{ # Excluded from CRAN checks, but run in localtests
-#' link <- selectDWD(res="hourly", var="sun", per="r", meta=TRUE)[2]
-#' file <- dataDWD(link, dir=locdir(), read=FALSE)
-#' readDWD(file)
+#' link <- selectDWD(res="hourly", var="solar", per="r", meta=TRUE)
+#' if(!any(endsWith(link,"pdf"))) stop("no pdf file here anymore") 
+#' # hourly/sun no longer has a pdf file anymore 2023-09
+#' link <- link[endsWith(link,"pdf")][1]
+#' file <- dataDWD(link, read=FALSE)
+#' readDWD(file) # opens in OS default PDF viewer
+#' 
+#' # for regular res/var combinations, use per=" " (since 1.8.29 2025-05-20)
+#' link <- selectDWD(res="daily", var="kl", per=" ", meta=TRUE)
+#' if(!any(endsWith(link,"pdf"))) stop("no pdf file here anymore") 
 #' }
 #' @param file      Name of file on harddrive, like e.g.
 #'                  monthly_kl_historical_DESCRIPTION_obsgermany_climate_monthly_kl_historical_en.pdf
