@@ -83,6 +83,8 @@
 #'              "recent" (up to date records from the last 1.5 years) or
 #'              "historical" (long time series). 
 #'              Can be abbreviated. To get both datasets, use `per="hr"`.
+#'              Use `per=" "` when using `meta=TRUE` (the DWD moved the description files in late 2024).
+#'              Use `per=""` for matching options from all periods.
 #'              DEFAULT: NA for interactive selection
 #' @param expand Logical: get all possible `res/var/per` combinations? 
 #'              Set to FALSE if you want only the given combinations.
@@ -110,6 +112,7 @@
 #'              DEFAULT: FALSE
 #' @param base  Single char: main directory of DWD ftp server.
 #'              Must be the same `base` used to create `findex`.
+#'              `sub("ftp:", "https:", dwdbase)` works fine.
 #'              DEFAULT: [`dwdbase`]
 #' @param meta  Logical: select Beschreibung file from `ismeta` entries in `findex`? 
 #'              See [`metaIndex`] for a compilation of all Beschreibung files.
@@ -253,7 +256,14 @@ if(expand)
 }
 
 # checks + output:
-if(sum(sel)<1 & !quiet) 
+nasel <- is.na(sel)
+if(any(nasel))
+  {
+  twarning("There are ", sum(nasel),"/",length(sel), " NAs in the selection. ",
+           "This should not happen, please debug. ",
+           "Probably some files are no longer present on the DWD server.")
+  }
+if(sum(sel,na.rm=TRUE)<1 & !quiet) 
  twarning("No entries in file index '", findexname, "' match your query\n  ",
           formatquery(), ".")
 return(paste0(base,"/",findex[sel,"path"]))
