@@ -42,6 +42,19 @@
 #' # 571'667 (2023-04-14)
 #' # 572'583 (2023-05-10)
 #' # 574'397 (2023-06-16)
+#' # 573'963 (2023-09-16)
+#' # 588'527 (2024-04-09)
+#' # 586'626 (2024-05-14)
+#' # 609'082 (2024-08-12)
+#' # 596'417 (2025-01-23)
+#' # 630'152 (2025-03-10)
+#' # 633'334 (2025-05-20)
+#' # 632'723 (2025-06-03)
+#' # 634'195 (2025-06-06)
+#' # 634'693 (2025-06-21)
+#' # 634'422 (2025-07-22)
+#' # 634'644 (2025-08-02)
+#' # 634'649 (2025-08-18)
 #' 
 #' # gridbase
 #' #  49'247 (2019-05-26)
@@ -70,6 +83,19 @@
 #' #  36'454 (2023-04-14)
 #' #  37'763 (2023-05-10)
 #' #  39'670 (2023-06-16)
+#' #  54'828 (2023-09-16)
+#' #  97'923 (2024-04-09)
+#' #  64'713 (2024-05-14)
+#' #  82'163 (2024-08-12)
+#' # 135'436 (2025-01-23)
+#' #  83'823 (2025-03-10)
+#' #  98'100 (2025-05-20)
+#' # 101'298 (2025-06-03)
+#' # 101'842 (2025-06-06)
+#' # 105'099 (2025-06-21)
+#' # 111'736 (2025-07-22)
+#' # 114'146 (2025-08-02)
+#' # 117'644 (2025-08-18)
 #' 
 #' @param dwdlocal Read "DWDdata/INDEX_of_DWD_.txt" instead of calling
 #'                 [indexFTP()]? DEFAULT: FALSE
@@ -92,17 +118,17 @@ messaget <- function(...) message(format(Sys.time(), "%T - "), ...)
 # get filenames on FTP server:
 if(dwdlocal) dwdfiles <- readLines("DWDdata/INDEX_of_DWD_.txt") else
  {
- messaget("Indexing FTP Server at dwdbase...")
- dwdfiles <- indexFTP(sleep=0, filename="", overwrite=TRUE)
+ messaget("Indexing FTP Server at dwdbase (expect 0,2,15,47,40s) ...")
+ dwdfiles <- indexFTP(sleep=0, filename="", dir="DWDdata", overwrite=TRUE)
  }
 if(grdlocal) grdfiles <- readLines("DWDdata/INDEX_of_DWD_grids.txt") else
  {
- messaget("Indexing FTP Server at gridbase...")
- grdfiles <- indexFTP("currentgindex", filename="grids", base=gridbase, overwrite=TRUE)
+ messaget("Indexing FTP Server at gridbase (expect 0,2,22,64s,2m,21,57s) ...")
+ grdfiles <- indexFTP(filename="grids", base=gridbase, dir="DWDdata", overwrite=TRUE)
  }
 
 messaget("Calling createIndex...")
-index <- createIndex(paths=dwdfiles, meta=TRUE, force=metaforce, overwrite=TRUE, checkwarn=FALSE)
+index <- createIndex(paths=dwdfiles, meta=TRUE, force=metaforce, dir="DWDdata", overwrite=TRUE, checkwarn=FALSE)
 
 # save indexes ----
 
